pub struct CachedQueueMap<Q>(pub(crate) DashMap<ChannelId, ChannelTicketQueue<ValueCachedQueue<Q>>, RandomState>);Tuple Fields
0: DashMap<ChannelId, ChannelTicketQueue<ValueCachedQueue<Q>>, RandomState>Trait Implementations
Sourceimpl<Q: Debug> Debug for CachedQueueMap<Q>
impl<Q: Debug> Debug for CachedQueueMap<Q>
Sourceimpl<Q> Default for CachedQueueMap<Q>
impl<Q> Default for CachedQueueMap<Q>
Sourceimpl<Q: TicketQueue> UnrealizedValue for CachedQueueMap<Q>
impl<Q: TicketQueue> UnrealizedValue for CachedQueueMap<Q>
Sourcefn unrealized_value(
&self,
channel_id: &ChannelId,
min_index: Option<u64>,
) -> Result<Option<HoprBalance>, TicketManagerError>
fn unrealized_value( &self, channel_id: &ChannelId, min_index: Option<u64>, ) -> Result<Option<HoprBalance>, TicketManagerError>
Returns the total value of the tickets in the given queue, or None if no such ticket queue exists.