pub struct OutgoingIndexCache {
cache: DashMap<(ChannelId, u32), Arc<OutgoingIndexEntry>>,
removed: DashSet<(ChannelId, u32)>,
}Fields
cache: DashMap<(ChannelId, u32), Arc<OutgoingIndexEntry>>removed: DashSet<(ChannelId, u32)>Implementations
Sourceimpl OutgoingIndexCache
impl OutgoingIndexCache
Sourcepub fn next(&self, channel_id: &ChannelId, epoch: u32) -> u64
pub fn next(&self, channel_id: &ChannelId, epoch: u32) -> u64
Returns the next outgoing index for the given channel and epoch.
Sourcepub fn upsert(&self, channel_id: &ChannelId, epoch: u32, index: u64) -> u64
pub fn upsert(&self, channel_id: &ChannelId, epoch: u32, index: u64) -> u64
Inserts the index for the given channel and epoch, or updates
the existing value if it is less than the provided index.
Returns the index value that is either:
- equal to
indexif no index for the given channel and epoch existed and the value was inserted, or - equal to the existing index value, if the provided
indexis less than the existing index value, or - equal to the provided
indexvalue if it is greater than the existing index value and the value is updated.