struct OutgoingIndexEntry {
index: AtomicU64,
is_dirty: AtomicBool,
}Expand description
Tracks outgoing ticket indices for a channel, starting from 0.
Fields
index: AtomicU64is_dirty: AtomicBoolImplementations
Sourceimpl OutgoingIndexEntry
impl OutgoingIndexEntry
Sourcefn increment(&self) -> u64
fn increment(&self) -> u64
Increments the index and marks it as dirty if within bounds.
The value returned is the value before the increment, saturating at [TicketBuilder::MAX_TICKET_INDEX].
Sourcefn set(&self, new_value: u64) -> u64
fn set(&self, new_value: u64) -> u64
Sets the index to the maximum of new_value and the current index value.
Marks the index as dirty if the value was increased.
Returns the new value of the index, saturating at [TicketBuilder::MAX_TICKET_INDEX].
Sourcefn mark_clean(&self)
fn mark_clean(&self)
Marks the index as clean.